/****************************************************************************
** Meta object code from reading C++ file 'game.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdiamond-17.12.3/src/game.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'game.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Game_t {
    QByteArrayData data[17];
    char stringdata0[188];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Game_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Game_t qt_meta_stringdata_Game = {
    {
QT_MOC_LITERAL(0, 0, 4), // "Game"
QT_MOC_LITERAL(1, 5, 12), // "boardResized"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 11), // "numberMoves"
QT_MOC_LITERAL(4, 31, 5), // "moves"
QT_MOC_LITERAL(5, 37, 25), // "pendingAnimationsFinished"
QT_MOC_LITERAL(6, 63, 14), // "updateGraphics"
QT_MOC_LITERAL(7, 78, 12), // "clickDiamond"
QT_MOC_LITERAL(8, 91, 5), // "point"
QT_MOC_LITERAL(9, 97, 11), // "dragDiamond"
QT_MOC_LITERAL(10, 109, 9), // "direction"
QT_MOC_LITERAL(11, 119, 17), // "animationFinished"
QT_MOC_LITERAL(12, 137, 7), // "message"
QT_MOC_LITERAL(13, 145, 11), // "stateChange"
QT_MOC_LITERAL(14, 157, 15), // "KDiamond::State"
QT_MOC_LITERAL(15, 173, 5), // "state"
QT_MOC_LITERAL(16, 179, 8) // "showHint"

    },
    "Game\0boardResized\0\0numberMoves\0moves\0"
    "pendingAnimationsFinished\0updateGraphics\0"
    "clickDiamond\0point\0dragDiamond\0direction\0"
    "animationFinished\0message\0stateChange\0"
    "KDiamond::State\0state\0showHint"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Game[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    1,   65,    2, 0x06 /* Public */,
       5,    0,   68,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   69,    2, 0x0a /* Public */,
       7,    1,   70,    2, 0x0a /* Public */,
       9,    2,   73,    2, 0x0a /* Public */,
      11,    0,   78,    2, 0x0a /* Public */,
      12,    1,   79,    2, 0x0a /* Public */,
      13,    1,   82,    2, 0x0a /* Public */,
      16,    0,   85,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,    8,
    QMetaType::Void, QMetaType::QPoint, QMetaType::QPoint,    8,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void,

       0        // eod
};

void Game::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Game *_t = static_cast<Game *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->boardResized(); break;
        case 1: _t->numberMoves((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->pendingAnimationsFinished(); break;
        case 3: _t->updateGraphics(); break;
        case 4: _t->clickDiamond((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 5: _t->dragDiamond((*reinterpret_cast< const QPoint(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 6: _t->animationFinished(); break;
        case 7: _t->message((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->stateChange((*reinterpret_cast< KDiamond::State(*)>(_a[1]))); break;
        case 9: _t->showHint(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Game::boardResized)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Game::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Game::numberMoves)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Game::pendingAnimationsFinished)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Game::staticMetaObject = {
    { &QGraphicsScene::staticMetaObject, qt_meta_stringdata_Game.data,
      qt_meta_data_Game,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Game::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Game::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Game.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int Game::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Game::boardResized()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Game::numberMoves(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Game::pendingAnimationsFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
