/****************************************************************************
** Meta object code from reading C++ file 'game-state.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdiamond-17.12.3/src/game-state.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'game-state.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDiamond__GameState_t {
    QByteArrayData data[18];
    char stringdata0[212];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDiamond__GameState_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDiamond__GameState_t qt_meta_stringdata_KDiamond__GameState = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KDiamond::GameState"
QT_MOC_LITERAL(1, 20, 7), // "message"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 4), // "text"
QT_MOC_LITERAL(4, 34, 12), // "stateChanged"
QT_MOC_LITERAL(5, 47, 15), // "KDiamond::State"
QT_MOC_LITERAL(6, 63, 5), // "state"
QT_MOC_LITERAL(7, 69, 13), // "pointsChanged"
QT_MOC_LITERAL(8, 83, 6), // "points"
QT_MOC_LITERAL(9, 90, 15), // "leftTimeChanged"
QT_MOC_LITERAL(10, 106, 7), // "seconds"
QT_MOC_LITERAL(11, 114, 9), // "addPoints"
QT_MOC_LITERAL(12, 124, 15), // "removedDiamonds"
QT_MOC_LITERAL(13, 140, 12), // "removePoints"
QT_MOC_LITERAL(14, 153, 19), // "resetCascadeCounter"
QT_MOC_LITERAL(15, 173, 12), // "startNewGame"
QT_MOC_LITERAL(16, 186, 6), // "update"
QT_MOC_LITERAL(17, 193, 18) // "forceRecalculation"

    },
    "KDiamond::GameState\0message\0\0text\0"
    "stateChanged\0KDiamond::State\0state\0"
    "pointsChanged\0points\0leftTimeChanged\0"
    "seconds\0addPoints\0removedDiamonds\0"
    "removePoints\0resetCascadeCounter\0"
    "startNewGame\0update\0forceRecalculation"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDiamond__GameState[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    1,   67,    2, 0x06 /* Public */,
       7,    1,   70,    2, 0x06 /* Public */,
       9,    1,   73,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    1,   76,    2, 0x0a /* Public */,
      13,    1,   79,    2, 0x0a /* Public */,
      14,    0,   82,    2, 0x0a /* Public */,
      15,    0,   83,    2, 0x0a /* Public */,
      16,    1,   84,    2, 0x0a /* Public */,
      16,    0,   87,    2, 0x2a /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,   10,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,

       0        // eod
};

void KDiamond::GameState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GameState *_t = static_cast<GameState *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->message((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->stateChanged((*reinterpret_cast< KDiamond::State(*)>(_a[1]))); break;
        case 2: _t->pointsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->leftTimeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->addPoints((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->removePoints((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->resetCascadeCounter(); break;
        case 7: _t->startNewGame(); break;
        case 8: _t->update((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->update(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GameState::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameState::message)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GameState::*_t)(KDiamond::State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameState::stateChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GameState::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameState::pointsChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GameState::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameState::leftTimeChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject KDiamond::GameState::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KDiamond__GameState.data,
      qt_meta_data_KDiamond__GameState,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KDiamond::GameState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDiamond::GameState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDiamond__GameState.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDiamond::GameState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KDiamond::GameState::message(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KDiamond::GameState::stateChanged(KDiamond::State _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KDiamond::GameState::pointsChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KDiamond::GameState::leftTimeChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
