// This file is generated by kconfig_compiler_kf5 from kdiamond.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings();

    /**
      Set Play an untimed game.
    */
    static
    void setUntimed( bool v )
    {
      if (!self()->isImmutable( QStringLiteral( "Untimed" ) ))
        self()->mUntimed = v;
    }

    /**
      Get Play an untimed game.
    */
    static
    bool untimed()
    {
      return self()->mUntimed;
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // Preferences
    bool mUntimed;

  private:
};

#endif

